# Morse Lang

A programming language written entirely in Morse code.

## Install
pip install -e .

## Run
morse examples/hello.mc

pip install -e . -- windows
python3 -m pip install -e . -- macbook
export PATH="/Users/blaz/Library/Python/3.9/bin:$PATH"